==> rucy-0.4.0.tar.gz: rucy-0.4.0/test/test_erb.rb <==
#!/usr/local/bin/ruby
# $Id: test_erb.rb,v 1.4 2004/10/30 09:01:07 toki Exp $

require 'rubyunit'
require 'pseudo_req_res'
require 'rucy/loader'

module TestRucy
  class TestERBFilter < RUNIT::TestCase
    include PseudoLogger
    include PseudoRequestResponse
    include PseudoDocument

    def setup
      super

      # target
      @loader = Rucy::SimpleLoader.new
      @loader.load('../mod_docs/erb.rb')
      @ERBFilter = @loader.const_get('ERBFilter')
      @erb = @ERBFilter.new
      @doc = Rucy::FilterDocument.new(self, @erb)
    end

    def test_erb
      @publish_messg_body = '<%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('foo', @messg_body)
    end

    def test_erb_script_name
      @publish_messg_body = '<%= ENV["SCRIPT_NAME"] + "," + ENV["PATH_INFO"] %>'.taint
      @request.method = 'GET'
      @request.path = '/foo/bar'
      @request.version = 'HTTP/1.1'
      @doc.publish('/foo', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('/foo', @publish_script_name)
      assert_equal('/foo/bar', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('/foo,/bar', @messg_body)
    end

    def test_erb_doc_path
      @publish_doc_path = '/foo/bar'
      @publish_messg_body = '<%= ENV["SCRIPT_NAME"] + "," + ENV["PATH_INFO"] %>'.taint
      @request.method = 'GET'
      @request.path = '/foo/bar'
      @request.version = 'HTTP/1.1'
      @doc.publish('/foo', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('/foo', @publish_script_name)
      assert_equal('/foo/bar', @publish_request_path)
      assert_equal('/foo/bar', @messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('/foo/bar,', @messg_body)
    end

    def test_erb_local_path
      @publish_local_path = File.join(File.expand_path('.'), 'test.rhtml')
      @publish_messg_body = '<%= ENV["SCRIPT_FILENAME"] %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_equal(File.join(File.expand_path('.'), 'test.rhtml'), @messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_match(@messg_body, /test\.rhtml$/)
    end

    def test_erb_request
      @publish_messg_body = '<%= __request__.header("Accept-Language") %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @request.set_header('Accept-Language', 'ja')
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('ja', @messg_body)
    end

    def test_erb_response
      @publish_messg_body = '<%
__response__.set_header("Cache-Control", "no-cache")
%><%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('no-cache', @messg_head.header('Cache-Control'))
      assert_equal('foo', @messg_body)
    end

    def test_erb_logger
      @publish_messg_body = '<%
__logger__.debug("Hello world.")
%><%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('foo', @messg_body)
      assert_match(@log_debug, /Hello world\.$/)
    end
  end

  class TestERBFilterBuilder < RUNIT::TestCase
    def setup
      @loader = Rucy::SimpleLoader.new
      @loader.load('../mod_docs/erb.rb')
      @ERBFilterBuilder = @loader.const_get('ERBFilterBuilder')
      @builder = @ERBFilterBuilder.instance
    end

    def test_set_filter_option
      @builder.set_filter_option(Hash.new)
    end

    def test_filter_name
      assert_equal('ERB', @builder.filter_name)
    end

    def test_filter_args
      args = @builder.filter_args
      assert_equal([ 'safe level', :select, %w[ 1 2 3 4 0 ] ], args[0])
      assert_equal([ 'pass auth', :bool, false ], args[1])
    end

    def test_new
      filter = @builder.new('1', false)
      assert_instance_of(@loader.const_get('ERBFilter'), filter)
    end
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/test/test_erb.rb <==
#!/usr/local/bin/ruby
# $Id: test_erb.rb,v 1.6 2005/02/26 17:43:33 toki Exp $

require 'rubyunit'
require 'pseudo_req_res'
require 'rucy/loader'

module TestRucy
  class TestERBFilter < RUNIT::TestCase
    include PseudoLogger
    include PseudoRequestResponse
    include PseudoDocument

    def setup
      super

      # target
      @loader = Rucy::SimpleLoader.new
      @loader.load('../mod_docs/erb.rb')
      @ERBFilter = @loader.const_get('ERBFilter')
      @erb = @ERBFilter.new
      @doc = Rucy::FilterDocument.new(self, @erb)
    end

    def test_erb
      @publish_messg_body = '<%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('foo', @messg_body)
    end

    def test_erb_script_name
      @publish_messg_body = '<%= ENV["SCRIPT_NAME"] + "," + ENV["PATH_INFO"] %>'.taint
      @request.method = 'GET'
      @request.path = '/foo/bar'
      @request.version = 'HTTP/1.1'
      @doc.publish('/foo', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('/foo', @publish_script_name)
      assert_equal('/foo/bar', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('/foo,/bar', @messg_body)
    end

    def test_erb_doc_path
      @publish_doc_path = '/foo/bar'
      @publish_messg_body = '<%= ENV["SCRIPT_NAME"] + "," + ENV["PATH_INFO"] %>'.taint
      @request.method = 'GET'
      @request.path = '/foo/bar'
      @request.version = 'HTTP/1.1'
      @doc.publish('/foo', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('/foo', @publish_script_name)
      assert_equal('/foo/bar', @publish_request_path)
      assert_equal('/foo/bar', @messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('/foo/bar,', @messg_body)
    end

    def test_erb_local_path
      @publish_local_path = File.join(File.expand_path('.'), 'test.rhtml')
      @publish_messg_body = '<%= ENV["SCRIPT_FILENAME"] %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_equal(File.join(File.expand_path('.'), 'test.rhtml'), @messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_match(@messg_body, /test\.rhtml$/)
    end

    def test_erb_request
      @publish_messg_body = '<%= __request__.header("Accept-Language") %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @request.set_header('Accept-Language', 'ja')
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('ja', @messg_body)
    end

    def test_erb_response
      @publish_messg_body = '<%
__response__.set_header("Cache-Control", "no-cache")
%><%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('no-cache', @messg_head.header('Cache-Control'))
      assert_equal('foo', @messg_body)
    end

    def test_erb_logger
      @publish_messg_body = '<%
__logger__.debug("Hello world.")
%><%= "foo" %>'.taint
      @request.method = 'GET'
      @request.path = '/'
      @request.version = 'HTTP/1.1'
      @doc.publish('', @request, @response, @logger)
      assert_equal(1, @publish_call)
      assert_equal('', @publish_script_name)
      assert_equal('/', @publish_request_path)
      assert_nil(@messg_head.doc_path)
      assert_nil(@messg_head.local_path)
      assert_equal('HTTP/1.1', @messg_head.version)
      assert_equal(200, @messg_head.status)
      assert_equal('OK', @messg_head.reason)
      assert_equal('text/plain', @messg_head.header('Content-Type'))
      assert_equal('foo', @messg_body)
      assert_match(@log_debug, /Hello world\.$/)
    end
  end

  class TestERBFilterBuilder < RUNIT::TestCase
    def setup
      @loader = Rucy::SimpleLoader.new
      @loader.load('../mod_docs/erb.rb')
      @ERBFilterBuilder = @loader.const_get('ERBFilterBuilder')
      @builder = @ERBFilterBuilder.instance
    end

    def test_set_filter_option
      @builder.set_filter_option(Hash.new)
    end

    def test_filter_name
      assert_equal('ERB', @builder.filter_name)
    end

    def test_filter_args
      args = @builder.filter_args
      assert_equal([ 'safe_level', 'safe level', :select, %w[ 1 2 3 4 0 ] ], args[0])
      assert_equal([ 'pass_auth', 'pass auth', :bool, false ], args[1])
    end

    def test_new
      filter = @builder.new('1', false)
      assert_instance_of(@loader.const_get('ERBFilter'), filter)
    end
  end
end
